# Streamlit XUI

An extended set of UI components for use in streamlit

- st_xui_sidemenu
- st_xui_placeholder

## Installation

```
pip install streamlit-xui
```

## Usage

Refer to the following files for example usage
- [placeholder](placeholder/README.md)
- [sidemenu](sidemenu/README.md)
